package cz.vutbr.fit.gja.AndroidStatus;

import android.Manifest;
import android.content.Context;
import android.content.pm.PackageManager;
import android.location.Address;
import android.location.Criteria;
import android.location.Geocoder;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.support.v4.app.ActivityCompat;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.widget.TextView;
import android.widget.Toast;

import java.io.IOException;
import java.util.List;
import java.util.Locale;

public class LocationActivity extends AppCompatActivity implements LocationListener {

    private TextView txtLon;
    private TextView txtLat;
    private TextView txtAddress;
    private LocationManager locationManager;
    private String provider;
    private List<Address> addresses;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_location);
        // nastavení titulku
        setTitle("Poloha");

        // zobrazení tlačítka zpět vedletitulku
        getSupportActionBar().setHomeButtonEnabled(true);

        // nabindování UI elementů na odpovídající objekty
        txtLon = this.findViewById(R.id.txtLon);
        txtLat = this.findViewById(R.id.txtLat);
        txtAddress = this.findViewById(R.id.txtAddress);

        // Get the location manager
        locationManager = (LocationManager) getSystemService(Context.LOCATION_SERVICE);
        // Define the criteria how to select the locatioin provider -> use
        // default
        Criteria criteria = new Criteria();
        provider = locationManager.getBestProvider(criteria, false);
        if (ActivityCompat.checkSelfPermission(this, Manifest.permission.ACCESS_FINE_LOCATION) != PackageManager.PERMISSION_GRANTED && ActivityCompat.checkSelfPermission(this, Manifest.permission.ACCESS_COARSE_LOCATION) != PackageManager.PERMISSION_GRANTED) {
            txtLat.setText("Poloha není dostupná");
            txtLon.setText("Poloha není dostupná");
            txtAddress.setText("Poloha není dostupná");
            return;
        }
        Location loc = locationManager.getLastKnownLocation(provider);

        // Inicializace polí pro polohu
        if (loc != null) {
            System.out.println("Provider " + provider + " has been selected.");
            onLocationChanged(loc);
        } else {
            txtLat.setText("Poloha není dostupná");
            txtLon.setText("Poloha není dostupná");
            txtAddress.setText("Poloha není dostupná");
        }
    }

    /* požadavek na pozice při startu okna */
    @Override
    protected void onResume() {
        super.onResume();
        if (ActivityCompat.checkSelfPermission(this, Manifest.permission.ACCESS_FINE_LOCATION) != PackageManager.PERMISSION_GRANTED && ActivityCompat.checkSelfPermission(this, Manifest.permission.ACCESS_COARSE_LOCATION) != PackageManager.PERMISSION_GRANTED) {

            return;
        }
        locationManager.requestLocationUpdates(provider, 400, 1, this);
    }

    /* Odebrání listeneru kdyse okno pozastaví */
    @Override
    protected void onPause() {
        super.onPause();
        locationManager.removeUpdates(this);
    }

    @Override
    public void onLocationChanged(Location location) {
        double lat = location.getLatitude();
        double lng = location.getLongitude();
        String addr = "";

        txtLat.setText(String.valueOf(lat));
        txtLon.setText(String.valueOf(lng));


        Geocoder geocoder;
        List<Address> addresses;
        geocoder = new Geocoder(this, Locale.getDefault());

        try {
            addresses = geocoder.getFromLocation(lat, lng, 1);
            for(int i = 0; i <=  addresses.get(0).getMaxAddressLineIndex() ; i++ ){
                addr += addresses.get(0).getAddressLine(i) + "\n";
            }

            txtAddress.setText(addr);
        } catch (IOException e) {
            e.printStackTrace();
        }

    }

    @Override
    public void onStatusChanged(String provider, int status, Bundle extras) {
        // TODO Auto-generated method stub

    }

    @Override
    public void onProviderEnabled(String provider) {
        Toast.makeText(this, "Enabled new provider " + provider,
                Toast.LENGTH_SHORT).show();

    }

    @Override
    public void onProviderDisabled(String provider) {
        Toast.makeText(this, "Disabled provider " + provider,
                Toast.LENGTH_SHORT).show();
    }


}