package cz.vutbr.fit.gja.breanPostProcessing;

import org.springframework.beans.BeansException;
import org.springframework.beans.factory.config.BeanPostProcessor;
import org.springframework.context.support.AbstractApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;

import cz.vutbr.fit.gja.Student;

/**
 * Brean postprocessing example.
 * This class demonstrates the very simple way to preprocess and postprocess bean object instances
 *
 */
public class BeanPostProcessorExample implements BeanPostProcessor {

	/**
	 * This method is called once for every instantiation. For prototype scope it can be multiple times, for default scope it's only once 
	 */
	public Object postProcessBeforeInitialization(Object bean, String beanName) throws BeansException {
		if (beanName.equals("studentbean")) { // Alias "id" property of the bean
			Student student = (Student) bean;
			student.setName("Secret Student"); // Custom init values
		}
		// This message is shown when bean object is created
		System.out.println("Creating bean: " + beanName + " (" + bean.getClass().toString() + ")");
		return bean;
	}

	/**
	 * Called after object is created and values are initiated
	 */
	public Object postProcessAfterInitialization(Object bean, String beanName) throws BeansException {
		System.out.println("Created bean: " + beanName + " (" + bean.getClass().toString() + ")");
		return bean;
	}

	public static void main(String[] args) {
		// Create context
		AbstractApplicationContext context = new ClassPathXmlApplicationContext("Beans.xml");
		
		// Create first student and show the info
		Student student1 = (Student) context.getBean("studentbean");
		student1.displayName();
		
		// Create another student and show the info
		Student student2 = (Student) context.getBean("studentbean");
		student2.displayName();
		
	}
}
