package cz.vutbr.fit.gja.scopes;

import org.springframework.beans.factory.BeanFactory;
import org.springframework.beans.factory.xml.XmlBeanFactory;
import org.springframework.core.io.ClassPathResource;
import org.springframework.core.io.Resource;

import cz.vutbr.fit.gja.Student;

/**
 * Basic scopes example.
 * Prototype allows multiple instances, singleton only one, which is default
 *
 */
public class ScopeExample {

	public static void main(String[] args) {
		Resource resource = new ClassPathResource("Beans.xml");
		BeanFactory factory = new XmlBeanFactory(resource);
		singleton(factory);
		prototype(factory);
	}

	/**
	 * Create 3 singletons and print their info
	 * @param factory Beans factory
	 */
	public static void singleton(BeanFactory factory) {
		Student[] students = new Student[3];

		for (int i = 0; i < students.length; i++) {
			students[i] = (Student) factory.getBean("studentbean");
		}
		System.out.println("\nListing singleton instances:");
		print_ids(students);
	}

	/**
	 * Create 3 student prototypes and print their info
	 * @param factory Beans factory
	 */
	public static void prototype(BeanFactory factory) {
		Student[] students = new Student[3];

		for (int i = 0; i < students.length; i++) {
			students[i] = (Student) factory.getBean("prototypestudentbean");
		}
		System.out.println("\nListing prototype instances:");
		print_ids(students);
	}

	/**
	 * Helper method to print object IDs
	 * @param objects array of object with ID fields
	 */
	public static void print_ids(Object[] objects) {
		for (int i = 0; i < objects.length; i++) {
			Object object = objects[i];
			try {
				int ID = (int) object.getClass().getDeclaredField("ID").get(object);
				System.out.println("\tObject[" + i + "].ID = " + ID);
			} catch (IllegalArgumentException | IllegalAccessException | NoSuchFieldException | SecurityException e) {
				e.printStackTrace();
			}
		}
	}
}
