<%@ page language="java" contentType="text/html; charset=UTF-8"
         pageEncoding="UTF-8"%>
<!DOCTYPE html>
<html>
    <head>
        <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
        <title>Expression Language example</title>
    </head>
    <body>
        
        <!-- 
        JSP Expression Language (EL) makes it possible to easily access application 
        data stored in JavaBeans components. JSP EL allows you to create expressions 
        both arithmetic and logical. Within a JSP EL expression, you can use integers, 
        floating point numbers, strings, the built-in constants true and false for 
        boolean values, and null.
        -->
        
        <!-- 
        The useBean action declares a JavaBean for use in a JSP. Once declared, 
        the bean becomes a scripting variable that can be accessed by both 
        scripting elements and other custom tags used in the JSP.
        -->
        <jsp:useBean id = "students" class = "cz.vutbr.fit.gja.jsp.StudentsBean"> 
            <jsp:setProperty name = "students" property = "firstName" value = "John"/>
            <jsp:setProperty name = "students" property = "lastName" value = "Doe"/>
        </jsp:useBean>

        <!-- 
        By defining a bean with id="students" it is possible to use this bean with EL
        with bot dot and bracket notation. 
        -->
        <h2>Expression language using the dot notation:</h2>
        <p>Student First Name: ${students.firstName}</p>
        <p>Student Last Name: ${students.lastName}</p>

        <h2>Expression language using the bracket notation:</h2>
        <p>Student First Name: ${students["firstName"]}</p>
        <p>Student Last Name: ${students["lastName"]}</p>

        <!-- 
        JSP EL Implicit Objects:
        The JSP expression language supports the following implicit objects:
            - pageScope - Scoped variables from page scope
            - requestScope - Scoped variables from request scope
            - sessionScope - Scoped variables from session scope
            - applicationScope - Scoped variables from application scope
            - param - Request parameters as strings
            - paramValues - Request parameters as collections of strings
            - header - HTTP request headers as strings
            - headerValues - HTTP request headers as collections of strings
            - initParam - Context-initialization parameters
            - cookie - Cookie values
            - pageContext - The JSP PageContext object for the current page
        -->
        <h2>Some implicit objects examples:</h2>
        <!-- pageContext -->
        <p>Incoming query string for a request: ${pageContext.request.queryString}</p>
        <!-- header -->
        <p>Header named user-agent: ${header["user-agent"]}</p>
        <!-- param -->
        <p>faculty parameter value: ${param.faculty}</p>
        
        <!-- The include directive inserts another file into the file -->
        <%@ include file="/include/backToMainPage.jsp" %>
    </body>
</html>
