package cz.vutbr.fit.gja.servlet;

import javax.servlet.*;
import java.util.*;

/**
 * Example of simple Filter class
 *
 * @author xhorna01@stud.fit.vutbr.cz
 */
public class LogFilter implements Filter {

    /**
     * init method is called only once when the servlet is started up
     * @param config filter configuration from web.xml
     * @throws ServletException if a servlet-specific error occurs
     */
    @Override
    public void init(FilterConfig config) throws ServletException {
        // Get init parameter 
        String initParam = config.getInitParameter("some-init-param");

        //Print the init parameter 
        System.out.println("Init-param value: " + initParam);
    }

    /**
     * This method is called when any HTTP request is intercepted.
     * 
     * @param request servlet request
     * @param response servlet response
     * @param chain chain of filters that are applied to each request
     * @throws java.io.IOException if an I/O error occurs
     * @throws ServletException if a servlet-specific error occurs
     */
    @Override
    public void doFilter(ServletRequest request, ServletResponse response,
            FilterChain chain) throws java.io.IOException, ServletException {

        // Get the IP address of client machine.
        String ipAddress = request.getRemoteAddr();

        // Log the IP address and current timestamp.
        System.out.println("[" + new Date().toString() + "] LogFilter: intercepted request from " + ipAddress);

        // Pass request back down the filter chain
        chain.doFilter(request, response);
    }
   
    /**
     * Called before the Filter instance is removed from service by the web container.
     */
    @Override
    public void destroy() {
        System.out.println("destroy method called on LogFilter.");
    }
}
